/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.model;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Collections;
import java.util.List;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.OneToOne;
import javax.persistence.Table;

import org.dive4elements.river.backend.SessionHolder;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.annotations.Type;

import com.vividsolutions.jts.geom.Point;

@Entity
@Table(name = "river_axes_km")
public class RiverAxisKm implements Serializable {

    private static final long serialVersionUID = 1L;

    private Integer id;
    private River river;
    private BigDecimal km;
    private Point geom;

    public RiverAxisKm() {
    }

    @Id
    @Column(name = "id")
    public Integer getId() {
        return this.id;
    }

    public void setId(final Integer id) {
        this.id = id;
    }

    @OneToOne
    @JoinColumn(name = "river_id")
    public River getRiver() {
        return this.river;
    }

    public void setRiver(final River river) {
        this.river = river;
    }

    @Column(name = "km")
    public BigDecimal getKm() {
        return this.km;
    }

    public void setKm(final BigDecimal km) {
        this.km = km;
    }

    @Column(name = "geom")
    @Type(type = "org.hibernatespatial.GeometryUserType")
    public Point getGeom() {
        return this.geom;
    }

    public void setGeom(final Point geom) {
        this.geom = geom;
    }

    /**
     * Returns a list of RiverAxisKm objects for a given river.
     *
     * @param riverid
     *            The ID of a river in the database.
     *
     * @return a list of RiverAxisKm objects.
     */
    public static List<RiverAxisKm> getRiverAxisKms(final int riverid) {
        final Session session = SessionHolder.HOLDER.get();

        final Query query = session.createQuery("from RiverAxisKm where river.id =:riverid");
        query.setParameter("riverid", riverid);

        final List<RiverAxisKm> list = query.list();

        return list;
    }

    public static List<RiverAxisKm> getRiverAxisKms(final int riverId, final double lowerKm, final double upperKm) {
        final Session session = SessionHolder.HOLDER.get();

        assert lowerKm <= upperKm;

        if (Double.isNaN(lowerKm) || Double.isInfinite(lowerKm))
            return Collections.emptyList();
        if (Double.isNaN(upperKm) || Double.isInfinite(upperKm))
            return Collections.emptyList();

        final BigDecimal fromKm = BigDecimal.valueOf(lowerKm);
        final BigDecimal toKm = BigDecimal.valueOf(upperKm);

        final Query query = session.createQuery("from RiverAxisKm where river.id =:riverid AND km >= :fromKm AND km <= :toKm");
        query.setParameter("riverid", riverId);
        query.setParameter("fromKm", fromKm);
        query.setParameter("toKm", toKm);

        final List<RiverAxisKm> list = query.list();

        return list;
    }
}